==> haskell-skylighting-core-0.14.3-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-core
version:              0.14.3
visibility:           public
id:                   skylighting-core-0.14.3-JeliWVLuHHB6GTVwszqz1M
key:                  skylighting-core-0.14.3-JeliWVLuHHB6GTVwszqz1M
license:              BSD-3-Clause
copyright:            (C) 2016-2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             syntax highlighting library
description:
    Skylighting is a syntax highlighting library.
    It derives its tokenizers from XML syntax
    definitions used by KDE'\''s KSyntaxHighlighting
    framework, so any syntax supported by that
    framework can be added. An optional command-line
    program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides the core highlighting
    functionality under a permissive license. It also
    bundles XML parser definitions licensed under the
    GPL.

category:             Text
abi:                  6723d42fd6488e56802f4163620d9bc9
exposed:              True
exposed-modules:
    Skylighting.Core Skylighting.Loader Skylighting.Parser
    Skylighting.Regex Skylighting.Styles Skylighting.Tokenizer
    Skylighting.Types

hidden-modules:
    Regex.KDE Regex.KDE.Regex Regex.KDE.Compile Regex.KDE.Match

import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-core-0.14.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-core-0.14.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-core-0.14.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-core
hs-libraries:         HSskylighting-core-0.14.3-JeliWVLuHHB6GTVwszqz1M
depends:
    aeson-2.1.2.1-1NeIvw5bSkQ9apxHmCtPBl
    attoparsec-0.14.4-H6DCtC2rXm7CWC54FRqEZL base-4.17.2.1
    base64-bytestring-1.2.1.0-GswEt3eOHYLA64palw0j2S binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-2s4OeiMO3UWBaQwGHjklqk
    colour-2.3.6-CLY4OzhkO79pVufYt5HDp containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    safe-0.3.21-3kF9VX2rOl78iX2OdZTXNo text-2.0.2 transformers-0.5.6.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xml-conduit-1.9.1.4-2PmlkjbW9FAF3ASgU662F1

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-core/html/skylighting-core.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-core-0.14.3-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-core
version:              0.14.3
visibility:           public
id:                   skylighting-core-0.14.3-5LizeBVhtW16RsMBkoLMrT
key:                  skylighting-core-0.14.3-5LizeBVhtW16RsMBkoLMrT
license:              BSD-3-Clause
copyright:            (C) 2016-2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             syntax highlighting library
description:
    Skylighting is a syntax highlighting library.
    It derives its tokenizers from XML syntax
    definitions used by KDE'\''s KSyntaxHighlighting
    framework, so any syntax supported by that
    framework can be added. An optional command-line
    program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides the core highlighting
    functionality under a permissive license. It also
    bundles XML parser definitions licensed under the
    GPL.

category:             Text
abi:                  20ed984e5a8f2d1c339071a4b1096302
exposed:              True
exposed-modules:
    Skylighting.Core Skylighting.Loader Skylighting.Parser
    Skylighting.Regex Skylighting.Styles Skylighting.Tokenizer
    Skylighting.Types

hidden-modules:
    Regex.KDE Regex.KDE.Regex Regex.KDE.Compile Regex.KDE.Match

import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-core-0.14.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-core-0.14.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-core-0.14.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-core
hs-libraries:         HSskylighting-core-0.14.3-5LizeBVhtW16RsMBkoLMrT
depends:
    aeson-2.1.2.1-Kx5U0b11hXDAcrJPuBeHuf
    attoparsec-0.14.4-4eygFQtTMUIB0P0RxBrkGo base-4.17.2.1
    base64-bytestring-1.2.1.0-GswEt3eOHYLA64palw0j2S binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-4NRudSZIbdgEwzMbC5HpSf
    colour-2.3.6-CLY4OzhkO79pVufYt5HDp containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    safe-0.3.21-HlwzjIK5TiIKPzF0RtoFLn text-2.0.2 transformers-0.5.6.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xml-conduit-1.9.1.4-3uUwAVag58SIuBpvKvM66W

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-core/html/skylighting-core.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
